@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2009-2010 B.A.T.M.A.N. contributors:
+/*
+ * Copyright (C) 2009-2011 B.A.T.M.A.N. contributors:
  *
  * Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -35,7 +35,7 @@ struct bat_host {
 	char name[HOST_NAME_MAX_LEN];
 } __attribute__((packed));
 
-void bat_hosts_init(void);
+void bat_hosts_init(int read_opt);
 struct bat_host *bat_hosts_find_by_name(char *name);
 struct bat_host *bat_hosts_find_by_mac(char *mac);
 void bat_hosts_free(void);
