@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007-2010 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2011 B.A.T.M.A.N. contributors:
  *
- * Andreas Langer <a.langer@q-dsl.de>, Marek Lindner <lindner_marek@yahoo.de>
+ * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -99,25 +99,7 @@ char *get_name_by_macstr(char *mac_str, int read_opt)
 	return get_name_by_macaddr(mac_addr, read_opt);
 }
 
-static int check_proc_dir(char *dir)
-{
-	struct stat st;
-
-	if (stat("/proc/", &st) != 0) {
-		printf("Error - the folder '/proc' was not found on the system\n");
-		printf("Please make sure that the proc filesystem is properly mounted\n");
-		return EXIT_FAILURE;
-	}
-
-	if (stat(dir, &st) == 0)
-		return EXIT_SUCCESS;
-
-	printf("Error - the folder '%s' was not found within the proc filesystem\n", dir);
-	printf("Please make sure that the batman-adv kernel module is loaded\n");
-	return EXIT_FAILURE;
-}
-
-int check_sys_dir(char *dir)
+static int check_sys_dir(char *dir)
 {
 	struct stat st;
 
@@ -135,23 +117,21 @@ int check_sys_dir(char *dir)
 	return EXIT_FAILURE;
 }
 
-int read_file(char *dir, char *fname, int read_opt)
+int read_file(char *dir, char *fname, int read_opt,
+	      float orig_timeout, float watch_interval)
 {
 	struct ether_addr *mac_addr;
 	struct bat_host *bat_host;
 	int res = EXIT_FAILURE;
+	float last_seen;
 	char full_path[500], *buff_ptr, *space_ptr, extra_char;
 	size_t len = 0;
-	ssize_t read;
 	FILE *fp = NULL;
 
 	if (read_opt & USE_BAT_HOSTS)
-		bat_hosts_init();
+		bat_hosts_init(read_opt);
 
-	if (strstr(dir, "/proc/")) {
-		if (check_proc_dir(dir) != EXIT_SUCCESS)
-			goto out;
-	} else if (strstr(dir, "/sys/")) {
+	if (strstr(dir, "/sys/")) {
 		if (check_sys_dir(dir) != EXIT_SUCCESS)
 			goto out;
 	}
@@ -173,24 +153,16 @@ open:
 		system("clear");
 
 read:
-	while ((read = getline(&line_ptr, &len, fp)) != -1) {
-		if (read_opt & SEARCH_ARGS) {
-			/* omit log lines which don't start with the correct tag */
-			if (strncmp(line_ptr, SEARCH_ARGS_TAG, strlen(SEARCH_ARGS_TAG)) == 0)
-				break;
-
-			continue;
-		}
-
+	while (getline(&line_ptr, &len, fp) != -1) {
 		/* the buffer will be handled elsewhere */
 		if (read_opt & USE_READ_BUFF)
 			break;
 
-		if (read_opt & LOG_MODE) {
-			/* omit log lines which don't start with the correct tag */
-			if (strncmp(line_ptr, BATMAN_ADV_TAG, strlen(BATMAN_ADV_TAG)) != 0)
+		/* skip timed out originators */
+		if (read_opt & NO_OLD_ORIGS)
+			if (sscanf(line_ptr, "%*s %f", &last_seen)
+			    && (last_seen > orig_timeout))
 				continue;
-		}
 
 		if (!(read_opt & USE_BAT_HOSTS)) {
 			printf("%s", line_ptr);
@@ -205,9 +177,17 @@ read:
 			*space_ptr = '\0';
 			extra_char = '\0';
 
-			if ((strlen(buff_ptr) == ETH_STR_LEN + 1) && (buff_ptr[ETH_STR_LEN] == ',')) {
-				extra_char = ',';
-				buff_ptr[ETH_STR_LEN] = '\0';
+			if (strlen(buff_ptr) == ETH_STR_LEN + 1) {
+				extra_char = buff_ptr[ETH_STR_LEN];
+				switch (extra_char) {
+				case ',':
+				case ')':
+					buff_ptr[ETH_STR_LEN] = '\0';
+					break;
+				default:
+					extra_char = '\0';
+					break;
+				}
 			}
 
 			if (strlen(buff_ptr) != ETH_STR_LEN)
@@ -229,16 +209,16 @@ read:
 				/* keep table format */
 				printf("%17s", bat_host->name);
 
+			goto written;
+
+print_plain_buff:
+			printf("%s", buff_ptr);
+
+written:
 			if (extra_char != '\0')
 				printf("%c", extra_char);
 
 			printf(" ");
-			goto written;
-
-print_plain_buff:
-			printf("%s ", buff_ptr);
-
-written:
 			buff_ptr = space_ptr + 1;
 		}
 
@@ -246,14 +226,14 @@ written:
 	}
 
 	if (read_opt & CONT_READ) {
-		sleep(1);
+		usleep(1000000 * watch_interval);
 		goto read;
 	}
 
 	if (read_opt & CLR_CONT_READ) {
 		if (fp)
 			fclose(fp);
-		sleep(1);
+		usleep(1000000 * watch_interval);
 		goto open;
 	}
 
@@ -275,10 +255,7 @@ int write_file(char *dir, char *fname, char *arg1, char *arg2)
 	char full_path[500];
 	ssize_t write_len;
 
-	if (strstr(dir, "/proc/")) {
-		if (check_proc_dir(dir) != EXIT_SUCCESS)
-			goto out;
-	} else if (strstr(dir, "/sys/")) {
+	if (strstr(dir, "/sys/")) {
 		if (check_sys_dir(dir) != EXIT_SUCCESS)
 			goto out;
 	}
@@ -311,21 +288,3 @@ out:
 		close(fd);
 	return res;
 }
-
-char *strchr_anyof(const char *s, const char *n)
-{
-	char *cur, *first = NULL;
-	size_t i, len;
-
-	if (s == NULL || n == NULL)
-		return first;
-
-	len = strlen(n);
-	for (i = 0; i < len; i++) {
-		cur = strchr(s, n[i]);
-		if (cur != NULL && (cur < first || first == NULL))
-			first = cur;
-	}
-
-	return first;
-}
