@@ -36,9 +36,11 @@
 #include "tcpdump.h"
 #include "bisect.h"
 #include "vis.h"
+#include "functions.h"
 #include <err.h>
 
 char mesh_dfl_iface[] = "bat0";
+char module_ver_path[] = "/sys/module/batman_adv/version";
 
 void print_usage(void) {
 	printf("Usage: batctl [options] commands \n");
@@ -58,6 +60,7 @@ void print_usage(void) {
 	printf(" \taggregation|ag  [0|1]             \tdisplay or modify the packet aggregation setting\n");
 	printf(" \tbonding|b       [0|1]             \tdisplay or modify the bonding mode setting\n");
 	printf(" \tfragmentation|f [0|1]             \tdisplay or modify the fragmentation mode setting\n");
+	printf(" \tap_isolation|ap [0|1]             \tdisplay or modify the ap isolation mode setting\n");
 	printf("\n");
 	printf(" \tping|p          <destination>     \tping another batman adv host via layer 2\n");
 	printf(" \ttraceroute|tr   <destination>     \ttraceroute another batman adv host via layer 2\n");
@@ -95,7 +98,18 @@ int main(int argc, char **argv)
 		goto err;
 
 	if (strcmp(argv[1], "-v") == 0) {
-		printf("batctl %s\n", SOURCE_VERSION);
+		printf("batctl %s [batman-adv: ", SOURCE_VERSION);
+
+		ret = read_file("", module_ver_path, USE_READ_BUFF | SILENCE_ERRORS, 0, 0);
+		if ((line_ptr) && (line_ptr[strlen(line_ptr) - 1] == '\n'))
+			line_ptr[strlen(line_ptr) - 1] = '\0';
+
+		if (ret == EXIT_SUCCESS)
+			printf("%s]\n", line_ptr);
+		else
+			printf("module not loaded]\n");
+
+		free(line_ptr);
 		exit(EXIT_SUCCESS);
 	}
 
@@ -188,6 +202,11 @@ int main(int argc, char **argv)
 		ret = handle_sys_setting(mesh_iface, argc - 1, argv + 1,
 					 SYS_FRAG, fragmentation_usage, sysfs_param_enable);
 
+	} else if ((strcmp(argv[1], "ap_isolation") == 0) || (strcmp(argv[1], "ap") == 0)) {
+
+		ret = handle_sys_setting(mesh_iface, argc - 1, argv + 1,
+					 SYS_AP_ISOLA, ap_isolation_usage, sysfs_param_enable);
+
 	} else if ((strcmp(argv[1], "bisect") == 0)) {
 
 		ret = bisect(argc - 1, argv + 1);
