@@ -1,5 +1,5 @@
-/* 
- * Copyright (C) 2009-2010 B.A.T.M.A.N. contributors:
+/*
+ * Copyright (C) 2009-2011 B.A.T.M.A.N. contributors:
  *
  * Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -21,4 +21,4 @@
 
 
 
-int ping(int argc, char **argv);
+int ping(char *mesh_iface, int argc, char **argv);
